---
title: 워드프레스 서비스 설정 방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 플러그인
seo:
  title: 워드프레스 서비스 설정 방법
  description: >-
    워드프레스 서비스 설정을 위해 필요한 부분들에 대한 안내를 드립니다. 포트원 관리자콘솔에서 PG채널 설정 후 워드프레스 우커머스 설정을
    위한 가이드를 확인해주세요.
  keywords:
    - 워드프레스
tags:
  - 워드프레스
  - 플러그인
pgCompanies:
  - null
searchTags:
  - wordpress
  - 워드프레스설정
  - 워드프레스
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="워드프레스 우커머스 이용 시 가장 기본적으로 필수적으로 설정이 필요한 항목을 안내드립니다." title="" />

<Callout content="우커머스 설정은 기본적으로 결제수단에 따라 각각 설정이 필요하오니 이용하실 결제수단에 한하여 설정을 진행해 주시기 바라며, 아래는 특정 결제수단을 예시로 표기해두었으니 실제 이용하실 결제대행사를 기준으로 적용바랍니다." icon="💡" title="참고사항" />

### **포트원 관리자콘솔에서 결제대행사 채널 설정**

포트원 관리자콘솔에 이용하실 결제대행사에 대한 연동 정보를 설정합니다.\
테스트 환경과 실 운영환경 중 원하시는 정보로 선택하여 설정 해주시기 바랍니다.

- 설정 경로 : [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제연동 > 연동관리 > 채널 관리 > 채널 추가 (테스트/실 운영환경 추가 방법이 상이합니다)

<Callout title="결제대행사별 채널 설정방법 보러 가기 ↗" icon="" />

#### **워드프레스 우커머스 설정**

워드프레스 사이트 내에서 포트원 관리자콘솔 연동을 위한 정보를 설정합니다.

- 설정 경로 : 워드프레스 관리자페이지 > 우커머스 > 설정 > 결제 > 리스트 중 아임포트(신용카드)와 같은 리스트 우측 '관리' 클릭 > 이미지 내 빨간색 박스 모두 설정\
  (아래 이미지는 신용카드에 대한 설정 예시이므로 다른 결제수단에서는 노출된 항목들을 모두 입력해 주시기 바랍니다)



- 고객사 식별코드(필수) : 포트원 관리자콘솔 > 결제연동 > 연동관리 > **식별코드 ・ API Keys** > V1 API > **고객사 식별코드** 값을 그대로 복사/붙여넣기 합니다.
- REST API 키 : 포트원 관리자콘솔 > 결제연동 > 연동관리 > **식별코드 ・ API Keys** > V1 API > **REST API Key** 값을 그대로 복사/붙여넣기 합니다.
- REST API Secret : 포트원 관리자콘솔 > 결제연동 > 연동관리 > **식별코드 ・ API Keys** > V1 API > **REST API Key** 값을 그대로 복사/붙여넣기 합니다.
- PG사 설정 : 이용하실 PG사(결제대행사)를 선택합니다.
- PG상점아이디 : PG사로부터 발급받은 상점아이디를 입력합니다.
  - 1번의 항목에서 설정한 상점아이디 값과 동일한 값입니다.
